@@ -1,19 +1,27 @@
 import asyncio
-from pyppeteer.browser import Browser
-from PuppeteerLibrary.custom_elements.SPage import SPage
 from robot.api.deco import not_keyword
+from robot.api import logger
+from pyppeteer.browser import Browser
+from robot.libraries.BuiltIn import BuiltIn
+from PuppeteerLibrary.custom_elements.SPage import SPage
 from PuppeteerLibrary.base.robotlibcore import DynamicCore
 from PuppeteerLibrary.keywords import (
+    AlertKeywords,
+    AlertKeywordsAsync,
     BrowserManagementKeywords,
     ElementKeywords,
     ElementKeywordsAsync,
     FormElementKeywords,
     FormElementKeywordsAsync,
+    JavascriptKeywords,
+    JavascriptKeywordsAsync,
+    ScreenshotKeywords,
+    ScreenshotKeywordsAsync,
     UtilityKeywords,
     WaitingKeywords,
     WaitingKeywordsAsync)
 
-__version__ = '0.3.0'
+__version__ = '0.4.1'
 
 
 class PuppeteerLibrary(DynamicCore):
@@ -36,6 +44,20 @@ class PuppeteerLibrary(DynamicCore):
     | link	       | Exact text a link has.	             | ``link:Home page``             |
     | partial link | Partial link text   	             | ``partial link:Home``          |
 
+    == Timeout ==
+    Timeout will use for Wait.. keywords. By default Puppeteer will use default timeout value if you
+    didn't specific in keywords argument.
+    Default Timeout is ``30 seconds``.
+
+    User can set new default timeout using ``Set Timeout`` keyword
+
+
+    *Time format*
+
+    All timeouts and waits can be given as numbers considered seconds (e.g. 0.5 or 42) or in Robot Framework's time syntax(e.g. 1.5 seconds or 1 min 30 s).
+
+    For more information about the time syntax see the Robot Framework User Guide.
+
     """
 
     ROBOT_LIBRARY_SCOPE = 'GLOBAL'
@@ -49,18 +71,26 @@ class PuppeteerLibrary(DynamicCore):
     async_libraries = []
 
     def __init__(self):
+        self.run_on_failure_keyword = 'Capture Page Screenshot'
+
         libraries = [
+            AlertKeywords(self),
             BrowserManagementKeywords(self),
             ElementKeywords(self),
             FormElementKeywords(self),
+            JavascriptKeywords(self),
+            ScreenshotKeywords(self),
             UtilityKeywords(self),
             WaitingKeywords(self)
         ]
         DynamicCore.__init__(self, libraries)
 
         self.async_libraries = [
+            AlertKeywordsAsync(self),
             ElementKeywordsAsync(self),
             FormElementKeywordsAsync(self),
+            JavascriptKeywordsAsync(self),
+            ScreenshotKeywordsAsync(self),
             WaitingKeywordsAsync(self)
         ]
 
@@ -86,3 +116,21 @@ class PuppeteerLibrary(DynamicCore):
     @not_keyword
     def get_browser(self) -> Browser:
         return self.browser
+
+    @not_keyword
+    def run_keyword(self, name, args, kwargs):
+        self._running_keyword = name
+        try:
+            return DynamicCore.run_keyword(self, name, args, kwargs)
+        except Exception:
+            self.failure_occurred()
+            raise
+        finally:
+            self._running_keyword = None
+
+    def failure_occurred(self):
+        try:
+            BuiltIn().run_keyword(self.run_on_failure_keyword)
+        except Exception as err:
+            logger.warn("Keyword '%s' could not be run on failure: %s"
+                        % (self.run_on_failure_keyword, err))
