@@ -45,12 +45,9 @@ class SPage(Page):
         else:
             return await self.querySelector(selector_value)
 
-    async def waitForSelector_with_selenium_locator(self, selenium_locator: str, timestr: str = None, visible=False, hidden=False):
-        if timestr is None:
-            timestr = '30s'
-        timesecs = timestr_to_secs(timestr)
+    async def waitForSelector_with_selenium_locator(self, selenium_locator: str, timeout: float, visible=False, hidden=False):
         options = {
-            'timeout': timesecs * 1000,
+            'timeout': timeout * 1000,
             'visible': visible,
             'hidden': hidden
         }
